---
title: "October, 2023"
date: 2023-10-02T09:05:36+03:00
author: "Alan Orth"
categories: ["Notes"]
---

## 2023-10-02

- Export CGSpace to check DOIs against Crossref
  - I found that [Crossref's metadata is in the public domain under the CC0 license](https://www.crossref.org/documentation/retrieve-metadata/rest-api/rest-api-metadata-license-information/)
  - One interesting thing is the abstracts, which are copyrighted by the copyright owner, meaning Crossref cannot waive the copyright under the terms of the CC0 license, because it is not theirs to waive
  - We can be on the safe side by using only abstracts for items that are licensed under Creative Commons

<!--more-->

- This GREL extracts the _text_ content of the `<jats:p>` tags (ie, no other JATS XML markup tags like `<jats:i>`, `<jats:sub>`, etc):

```console
forEach(value.parseXml().select("jats|p"),i,i.xmlText()).join("")
```

- Note that we need to use `select("jats|p")` instead of `select("jats:p")` for OpenRefine's parseXml, and we need to `join()` on the end
- I updated metadata for about 3,000 items using Crossref metadata
  - I stripped trailing periods for titles where they were missing on the Crossref titles
  - I copied abstracts for about 600 items that were missing them, for items that were Creative Commons
  - I updated publishers for a few thousand more where ours and Crossref disagreed, checking a handful manually first
- I also added subjects to the `crossref_doi_lookup.py` script to see if they will be useful for us
  - When checking with csv-metadata-quality I can validate those subjects against AGROVOC and add them if they are valid

## 2023-10-03

- I added the item type to the collection subscription email on DSpace 6
  - It's done differently on DSpace 7 so I'll have to see how to do it there...
- Test a patch that fixes a bug with item versioning disabled in DSpace 7
  - I hadn't realized that DSpace 7 defaulted to versioning being enabled, whereas we never used this in DSpace 6 (yet)
- Submit [an issue regarding duplicate Discovery sort fields](https://github.com/DSpace/DSpace/issues/9104) in DSpace 7

## 2023-10-05

- Some discussion this week about issue and online dates for journal articles, with regards to PRMS
  - I looked more closely at the [Crossref API docs](https://github.com/CrossRef/rest-api-doc/blob/master/api_format.md) and realized (again) that their "issue" date is not the same as our issue date—they take the earlier of the print and online dates!
  - Also, *very many* items have no print date at all, perhaps due to delays, errors, or simply because the journal is "online only"!
  - I suggested again that PRMS should consider both, and take the earlier of the two, then make sure whether the date is in the current reporting period
  - I managed to find 80 items with print publishing dates from 2023 and updated those from Crossref, but for the rest we will have to think about how we handle them

## 2023-10-06

- More discussion about dates after looking closely at them yesterday and today
  - Crossref doesn't always have both issued and online dates—sometimes they have one, sometimes the other, and sometimes both, so we cannot rely on them 100% for that.
  - In some cases, the item is available online for months (or even a year!), but has not been included in an issue yet, and thus has no "issue" date, for example:
    - https://doi.org/10.1002/csc2.20914 <--- published online January 2023!
    - https://doi.org/10.1111/mcn.13401 <--- published online July 2022!
  - Even journals make mistakes: this journal article was "issued" in 2022, but online in 2023! This is not Crossref's fault, but the journal's!
    - https://doi.org/10.1186/s40066-022-00400-6
  - I found a bunch more strange cases regarding dates and recommended to PRMS team that they use the earlier of the issued and online dates
- Meet with Aditi to start discussing the scope of knowledge products we can get for the CGIAR climate change synthesis

## 2023-10-07

- I spent a few hours (!) debugging an issue in Python when downloading PDFs
  - I think it ended up being due to `requests_cache`!!! Grrrr
  - On a positive note I've greatly refactored my script for discovering and downloading PDFs from Unpaywall
- Export CGSpace to check for missing Initiative collection mappings
- Start a harvest on AReS

<!-- vim: set sw=2 ts=2: -->
